Elements
========

.. toctree::
  :hidden:
  :maxdepth: 1


.. automodule:: burdoc.elements
   :members:

.. contents::
    :depth: 2
    :local:
    :backlinks: top

LayoutElement
-------------
.. autoclass:: burdoc.elements.element.LayoutElement
   :members:



LayoutElementGroup
------------------

.. autoclass:: burdoc.elements.element.LayoutElementGroup
   :members:


Aside
-----
.. automodule:: burdoc.elements.aside
   :members:


Bbox
----

.. automodule:: burdoc.elements.bbox
   :members:


DrawingElement
--------------

.. automodule:: burdoc.elements.drawing
   :members:


Font
----
.. automodule:: burdoc.elements.font
   :members:
   

ImageElement
------------

.. automodule:: burdoc.elements.image
   :members:


LineElement
-----------
.. automodule:: burdoc.elements.line
   :members:


PageSection
-----------

.. automodule:: burdoc.elements.section
   :members:


Span
----
.. automodule:: burdoc.elements.span
   :members:


Table
-----    
.. automodule:: burdoc.elements.table
   :members:


TextBlock
---------

.. automodule:: burdoc.elements.textblock
   :members:
   

TextList
--------
.. automodule:: burdoc.elements.textlist
   :members:






    
